@@ -35,24 +35,19 @@ import java.util.Set;
  */
 public abstract class RequestHandler {
 
-    // Restrictor for restricting operations
-    protected Restrictor restrictor;
+    // RestriOctor for restricting operations
+    protected final Restrictor restrictor;
 
     protected RequestHandler(Restrictor pRestrictor) {
         restrictor = pRestrictor;
     }
 
-    protected void checkForType() {
-        if (!restrictor.isTypeAllowed(getType())) {
-            throw new SecurityException("Command type " +
-                    getType() + " not allowed due to policy used");
-        }
-    }
+
     /**
      * The type of request which can be served by this handler
      * @return the request typ of this handler
      */
-    abstract public JmxRequest.Type getType();
+    public abstract JmxRequest.Type getType();
 
     /**
      * Override this if you want all servers as list in the argument, e.g.
@@ -89,6 +84,16 @@ public abstract class RequestHandler {
         return doHandleRequest(server,request);
     }
 
+    /**
+     * Check whether there is a restriction on the type to apply
+     */
+    protected void checkForType() {
+        if (!restrictor.isTypeAllowed(getType())) {
+            throw new SecurityException("Command type " +
+                    getType() + " not allowed due to policy used");
+        }
+    }
+
     /**
      * Abstract method to be subclassed by a concrete handler for performing the
      * request.
@@ -102,7 +107,7 @@ public abstract class RequestHandler {
      * @throws ReflectionException
      * @throws MBeanException
      */
-    abstract protected Object doHandleRequest(MBeanServer server,JmxRequest request)
+    protected abstract Object doHandleRequest(MBeanServer server,JmxRequest request)
             throws InstanceNotFoundException, AttributeNotFoundException, ReflectionException, MBeanException;
 
     /**
